wipe;
model BasicBuilder -ndm 2 -ndf 3;

set tcl_precision 16;

# --- UNITS
set in 1.;
set kip 1.;
set sec 1.;
set kN [expr 0.2248089431*$kip];
set ksi [expr $kip/pow($in,2)];
set psi [expr $ksi/1000.];
set ft [expr 12.*$in];
set lb [expr $kip/1000.];
set pcf [expr $lb/pow($ft,3)];
set cm [expr $in/2.54];
set mm [expr $in/25.4];
set meter [expr 100.*$cm];
set MPa [expr 145*$psi];
set GPa [expr 1000*$MPa];
set PI [expr 2*asin(1.0)];
set g [expr 32.2*$ft/pow($sec,2)];
set U 1.e10;
set u [expr 1/$U];

# --- DEFINE MATERIAL MODELS
set SteelMat 1;
set ConcVertMat 2;
set ConcHorizMat 3;
set ConcDiagMat 4;
set ElasticMat 5;

# Steel02
set fy 		61.5;
set fu		92.0;
set esh		0.015;
set eult	0.12;
set Es 		29000.;
set Esh		4000.;

set R0 20.;	
set cR1 0.925;
set cR2 0.15;
set a1 0.05
set a2 1.
set a3 0.
set a4 1.

uniaxialMaterial Steel02 $SteelMat $fy $Es 0.03 $R0 $cR1 $cR2 $a1 $a2 $a3 $a4

# ConcretewBeta
set alpha	[expr 0.5]
set lambda	[expr 0.75]

set fpc  	[expr -4.63];
set ec0 	[expr -0.002];
set Ec		[expr 4000.]
set fcint 	[expr -0.001];
set Eu	 	[expr $lambda*($fpc/$ec0) + (1.-$lambda)*$Ec];
set ecint 	[expr (-0.002 + $fpc/$Eu)*(23.6/16.) + (-0.002 - $fpc/$Eu)];
set fcres 	[expr 0.];	
set ecres 	[expr -1.];

set ft 		[expr 0.267];
set ftint 	[expr 0.001];
set etint 	[expr 3.*($ft/$Ec)*(23.6/16.)];
set ftres 	[expr 0.0];
set etres 	[expr 1.0];

uniaxialMaterial ConcretewBeta $ConcVertMat $fpc $ec0 $fcint $ecint $fcres $ecres $ft $ftint $etint $ftres $etres -E $Ec -alpha $alpha -lambda $lambda 

set ecint 	[expr (-0.002 + $fpc/$Eu)*(23.6/16.33) + (-0.002 - $fpc/$Eu)];
set etint 	[expr 3.*($ft/$Ec)*(23.6/16.33)];

uniaxialMaterial ConcretewBeta $ConcHorizMat $fpc $ec0 $fcint $ecint $fcres $ecres $ft $ftint $etint $ftres $etres -E $Ec -alpha $alpha -lambda $lambda 

set ecint 	[expr (-0.002 + $fpc/$Eu)*(23.6/22.864) + (-0.002 - $fpc/$Eu)];

set ft 		[expr 0.001];
set ftint 	[expr 0.0];
set etint 	[expr 1.0];
set ftres 	[expr 0.0];
set etres 	[expr 1.0];

set bint 	[expr 0.3];
set ebint 	[expr 0.01*(23.6/22.864)];
set bres 	[expr 0.1];
set ebres 	[expr 0.025*(23.6/22.864)];

uniaxialMaterial ConcretewBeta $ConcDiagMat $fpc $ec0 $fcint $ecint $fcres $ecres $ft $ftint $etint $ftres $etres -E $Ec -alpha [expr 0.267/$ft*$alpha] -beta $bint $ebint $bres $ebres

uniaxialMaterial Elastic $ElasticMat $Ec

# --- DEFINE NODAL PROPERTIES
node 1  	2.5 	0.0
node 2  	18.833 	0.0
node 3  	35.167 	0.0
node 4  	51.5 	0.0

node 11  	2.5  	16.0
node 12  	18.833	16.0
node 13  	35.167	16.0
node 14  	51.5  	16.0

node 21  	2.5  	32.0
node 22  	18.833	32.0
node 23  	35.167	32.0
node 24  	51.5  	32.0

node 31  	2.5  	48.0
node 32  	18.833	48.0
node 33  	35.167	48.0
node 34  	51.5  	48.0

# set the boundary conditions
fix 1  	1 	1 	1
fix 2  	1 	1 	1
fix 3  	1 	1 	1
fix 4  	1 	1 	1

fix 11 	0	0 	1
fix 12 	0	0 	1
fix 13 	0	0 	1
fix 14 	0	0 	1

fix 21 	0	0 	1
fix 22 	0	0 	1
fix 23 	0	0 	1
fix 24 	0	0 	1

fix 31 	0	0 	1
fix 32 	0	0 	1
fix 33 	0	0 	1
fix 34 	0	0 	1

# --- DEFINE ELEMENTS
set AconcOuter [expr 6.*5.];
set AsteelOuter [expr 2.*0.2];
set AconcInner [expr 6.*22.];
set AsteelInner [expr 1.5*0.2];

set AconcHoriz [expr 6.*16.];
set AsteelHoriz [expr 4.*0.2/48.*16.];

set AconcDiag [expr 6.*11.2];

# Vertical concrete
element truss 	1 	1 	11 	$AconcOuter	$ConcVertMat
element truss 	2 	2 	12 	$AconcInner	$ConcVertMat
element truss 	3 	3 	13 	$AconcInner	$ConcVertMat
element truss 	4 	4 	14 	$AconcOuter	$ConcVertMat

element truss 	11 	11 	21 	$AconcOuter	$ConcVertMat
element truss 	12 	12 	22 	$AconcInner	$ConcVertMat
element truss 	13 	13 	23 	$AconcInner	$ConcVertMat
element truss 	14 	14 	24 	$AconcOuter	$ConcVertMat

element truss 	21 	21 	31 	$AconcOuter	$ConcVertMat
element truss 	22 	22 	32 	$AconcInner	$ConcVertMat
element truss 	23 	23 	33 	$AconcInner	$ConcVertMat
element truss 	24 	24 	34 	$AconcOuter	$ConcVertMat

# Vertical steel
element truss 	101 	1 	11 	$AsteelOuter	$SteelMat
element truss 	102 	2 	12 	$AsteelInner	$SteelMat
element truss 	103 	3 	13 	$AsteelInner	$SteelMat
element truss 	104 	4 	14 	$AsteelOuter	$SteelMat

element truss 	111 	11 	21 	$AsteelOuter	$SteelMat
element truss 	112 	12 	22 	$AsteelInner	$SteelMat
element truss 	113 	13 	23 	$AsteelInner	$SteelMat
element truss 	114 	14 	24 	$AsteelOuter	$SteelMat

element truss 	121 	21 	31 	$AsteelOuter	$SteelMat
element truss 	122 	22 	32 	$AsteelInner	$SteelMat
element truss 	123 	23 	33 	$AsteelInner	$SteelMat
element truss 	124 	24 	34 	$AsteelOuter	$SteelMat

# Horizontal concrete
element truss 	31 	11 	12 	$AconcHoriz	$ConcHorizMat
element truss 	32 	12 	13 	$AconcHoriz	$ConcHorizMat
element truss 	33 	13 	14 	$AconcHoriz	$ConcHorizMat

element truss 	41 	21 	22 	$AconcHoriz	$ConcHorizMat
element truss 	42 	22 	23 	$AconcHoriz	$ConcHorizMat
element truss 	43 	23 	24 	$AconcHoriz	$ConcHorizMat

# Horizontal steel
element truss 	131 	11 	12 	$AsteelHoriz	$SteelMat
element truss 	132 	12 	13 	$AsteelHoriz	$SteelMat
element truss 	133 	13 	14 	$AsteelHoriz	$SteelMat

element truss 	141 	21 	22 	$AsteelHoriz	$SteelMat
element truss 	142 	22 	23 	$AsteelHoriz	$SteelMat
element truss 	143 	23 	24 	$AsteelHoriz	$SteelMat

# Diagonal concrete
element Truss2 	201 	1	12	2	11  $AconcDiag	$ConcDiagMat
element Truss2 	202 	2	11	1	12 	$AconcDiag	$ConcDiagMat
element Truss2 	203 	2	13	3	12  $AconcDiag	$ConcDiagMat
element Truss2 	204 	3	12	2	13 	$AconcDiag	$ConcDiagMat
element Truss2 	205 	3	14	4	13  $AconcDiag	$ConcDiagMat
element Truss2 	206 	4	13	3	14 	$AconcDiag	$ConcDiagMat

element Truss2 	211 	11	22	12	21  $AconcDiag	$ConcDiagMat
element Truss2 	212 	12	21	11	22 	$AconcDiag	$ConcDiagMat
element Truss2 	213 	12	23	13	22  $AconcDiag	$ConcDiagMat
element Truss2 	214 	13	22	12	23 	$AconcDiag	$ConcDiagMat
element Truss2 	215 	13	24	14	23  $AconcDiag	$ConcDiagMat
element Truss2 	216 	14	23	13	24 	$AconcDiag	$ConcDiagMat

element Truss2 	221 	21	32	22	31  $AconcDiag	$ConcDiagMat
element Truss2 	222 	22	31	21	32 	$AconcDiag	$ConcDiagMat
element Truss2 	223 	22	33	23	32  $AconcDiag	$ConcDiagMat
element Truss2 	224 	23	32	22	33 	$AconcDiag	$ConcDiagMat
element Truss2 	225 	23	34	24	33  $AconcDiag	$ConcDiagMat
element Truss2 	226 	24	33	23	34 	$AconcDiag	$ConcDiagMat

# Top loading elements
geomTransf Linear 1

node 100  	27.0 	78.0
fix 100 	0 	0 	1

element elasticBeamColumn 301 	31 	32	[expr 30.*24.]	 3600.  [expr pow(30.,3.)*24./3.]  1
element elasticBeamColumn 302 	32 	33	[expr 30.*24.]	 3600.  [expr pow(30.,3.)*24./3.]  1
element elasticBeamColumn 303 	33 	34	[expr 30.*24.]	 3600.  [expr pow(30.,3.)*24./3.]  1

element truss 	311 	31	100 	[expr 30.*24.]		$ElasticMat
element truss 	314 	34	100 	[expr 30.*24.]		$ElasticMat

# --- DEFINE GRAVITY LOADING
set controlNode 100;
pattern Plain 2 Linear -factor 1 {
   load $controlNode 0.0 -75. 0.0;
}

# --- APPLY GRAVITY LOAD
set Tol 1.0e-6; 
constraints Transformation
numberer Plain
system UmfPack 
set NstepGravity 10;
set DGravity [expr 1./$NstepGravity];
integrator LoadControl $DGravity;

for {set i 0} {$i < $NstepGravity} {incr i 1} {
	test NormDispIncr $Tol 20 0;
	algorithm Newton; 
	analysis Static;
	set ok [analyze 1];
	if {$ok != 0} {
		remove recorders;
		return -1
	}
};
puts "Finished applying gravity load"
loadConst -time 0.0

# --- DEFINE CYCLIC LOADING
set load 1.0;
pattern Plain 1 Linear -factor 1 {
   load $controlNode $load 0.0 0.0;
}

# --- DEFINE RECORDERS
recorder Node -file "MassoneWall_FreeDisp.out" -load -nodes $controlNode -dof 1 disp

recorder Element -file "MassoneWall_diagonalStressStrain.out" -load -ele 201 202 203 204 205 206 -material stressStrain
recorder Element -file "MassoneWall_diagonalStressStrain2.out" -load -ele 211 212 213 214 215 216 -material stressStrain
recorder Element -file "MassoneWall_diagonalStressStrain3.out" -load -ele 221 222 223 224 225 226 -material stressStrain
recorder Element -file "MassoneWall_diagonalBeta.out" -load -ele 201 202 203 204 205 206 -material beta
recorder Element -file "MassoneWall_diagonalBeta2.out" -load -ele 211 212 213 214 215 216 -material beta
recorder Element -file "MassoneWall_diagonalBeta3.out" -load -ele 221 222 223 224 225 226 -material beta
recorder Element -file "MassoneWall_vertStressStrain.out" -load -ele 1 2 3 4 -material stressStrain
recorder Element -file "MassoneWall_vertSteelStressStrain.out" -load -ele 101 102 103 104 -material stressStrain
recorder Element -file "MassoneWall_horizStressStrain.out" -load -ele 131 132 133 -material stressStrain

# --- LOADING LOOP
set file [open "MassoneWall_inputCyclic.dat" r];
set factor [expr 1.0];
set Tol 1.0e-4;			# convergence tolerance for test

constraints Transformation
numberer Plain
system UmfPack 

set d1 0.;
set Nstep 10;
set startT [clock seconds]

while {[gets $file temp] > 0} {
	foreach d2 $temp {
		set d2 [expr {$factor*$d2}];
		set DLoad [expr {($d2 - $d1)/$Nstep}];
		puts [expr {$d1 + $Nstep*$DLoad}];
		
		for {set i 0} {$i < $Nstep} {incr i 1} {
			test NormDispIncr $Tol 10 0
			algorithm Newton
			integrator DisplacementControl $controlNode 1 $DLoad
			analysis Static
		    set ok [analyze 1]
			if {$ok != 0} {
				puts "Trying Newton with Initial Tangent.."
				test NormDispIncr $Tol 4000 0
				algorithm Newton -initial
				integrator DisplacementControl $controlNode 1 $DLoad
				analysis Static
				set ok [analyze 1]
			}
			if {$ok != 0} {
				remove recorders;
				return -1
		    };
		};
		set d1 $d2;
	}
}
puts "finished analysis ------"
remove recorders;

set endT [clock seconds]
puts "Execution time: [expr $endT-$startT] seconds."