globalForceDispl = load('MassoneWall_FreeDisp.out');
diagStressStrain1 = load('MassoneWall_diagonalStressStrain.out');
diagStressStrain2 = load('MassoneWall_diagonalStressStrain2.out');
diagStressStrain3 = load('MassoneWall_diagonalStressStrain3.out');
diagBeta = load('MassoneWall_diagonalBeta.out');
diagBeta2 = load('MassoneWall_diagonalBeta2.out');
diagBeta3 = load('MassoneWall_diagonalBeta3.out');
horizStressStrain = load('MassoneWall_horizStressStrain.out');

%%

t = find(diagStressStrain3(:,5) <= -0.002);
firstSoftening = t(1);
t = find(diagStressStrain3(:,5) <= -0.00412);
firstCrushing = t(1);

%%

f = figure('units','normalized','outerposition',[0 0 0.7 1.0]);
set(f,'DefaultAxesFontSize', 12, ...
'DefaultAxesFontAngle', 'Italic', ...
'DefaultAxesFontName', 'Arial', ...
'DefaultTextFontSize', 12, ...
'DefaultTextFontName', 'Arial', ...
'DefaultTextVerticalAlignment', 'middle', ...
'DefaultTextHorizontalAlignment', 'left');

subplot(2,2,3)
hold on
plot(globalForceDispl(:,2),globalForceDispl(:,1),'k','linewidth',2)
plot([-0.6,0.8],[0,0],'k-')
plot([0,0],[-150,150],'k-')
plot(globalForceDispl(firstSoftening,2),globalForceDispl(firstSoftening,1),'co','markersize',8,'linewidth',3)
plot(globalForceDispl(firstCrushing,2),globalForceDispl(firstCrushing,1),'r^','markersize',8,'linewidth',3)
axis([-0.6,0.8,-150,150]);
set(gca,'XTick',-0.6:0.2:0.8,'YTick',-150:50:150)
ylabel('Lateral force (kips)')
xlabel('Top displacement (in)')
ax2 = axes('Position',get(gca,'Position'),'XAxisLocation','top','YAxisLocation','right','Color','none','XColor','k','YColor','k');
set(ax2,'Xlim',[-0.6/48*100,0.8/48*100])
set(ax2,'XTick',[-floor(0.6/48*100/0.5):0.5:floor(0.8/48*100/0.5)])
set(ax2,'YTick',[])
xlabel(ax2,'Drift ratio (%)')

subplot(2,2,4)
hold on
box on
plot(-10,-10,'co','markersize',8,'linewidth',3)
plot(-10,-10,'r^','markersize',8,'linewidth',3)
plot(diagStressStrain3(:,5)*100,diagStressStrain3(:,4),'k','linewidth',2)
plot([-1.5,1.0],[0,0],'k-')
plot([0,0],[-3,0.5],'k-')
plot(diagStressStrain3(firstSoftening,5)*100,diagStressStrain3(firstSoftening,4),'co','markersize',8,'linewidth',3)
plot(diagStressStrain3(firstCrushing,5)*100,diagStressStrain3(firstCrushing,4),'r^','markersize',8,'linewidth',3)
axis([-1.5,1.0,-3,0.5]);
legend('diagonal \epsilon \leq -0.2%','diagonal \epsilon \leq -0.41%','Location','SE')
ylabel('Stress (ksi)')
xlabel('Strain (%)')
title('Diagonal E1')

%%

f = figure('units','normalized','outerposition',[0 0 0.4 1.0]);
set(f,'DefaultAxesFontSize', 11, ...
'DefaultAxesFontAngle', 'Italic', ...
'DefaultAxesFontName', 'Arial', ...
'DefaultTextFontSize', 11, ...
'DefaultTextFontName', 'Arial', ...
'DefaultTextVerticalAlignment', 'middle', ...
'DefaultTextHorizontalAlignment', 'left');

totalLen = length(globalForceDispl);

subplot(5,1,1)
hold on
box on
plot(globalForceDispl(:,2)*100/48,'k','linewidth',2)
plot([1,totalLen],[0,0],'k')
plot(firstSoftening,globalForceDispl(firstSoftening,2)*100/48,'co','markersize',6,'linewidth',3)
plot(firstCrushing,globalForceDispl(firstCrushing,2)*100/48,'r^','markersize',6,'linewidth',3)
xlim([0,totalLen])
set(gca,'XTick',[])
ylim([-1,1.5])
set(gca,'XTick',[],'YTick',-1:0.5:1.5)
ylabel({'Drift ratio (%)'})

subplot(5,1,2)
hold on
box on
plot(globalForceDispl(:,1),'k','linewidth',2)
plot([1,totalLen],[0,0],'k')
plot(firstSoftening,globalForceDispl(firstSoftening,1),'co','markersize',6,'linewidth',3)
plot(firstCrushing,globalForceDispl(firstCrushing,1),'r^','markersize',6,'linewidth',3)
xlim([0,totalLen])
set(gca,'XTick',[])
ylim([-150,150])
set(gca,'XTick',[],'YTick',-150:75:150)
ylabel({'Lateral Force (kips)'})

subplot(5,1,3)
hold on
box on
plot(diagStressStrain3(:,5)*100,'k','linewidth',2)
plot([1,totalLen],[0,0],'k')
plot(firstSoftening,diagStressStrain3(firstSoftening,5)*100,'co','markersize',6,'linewidth',3)
plot(firstCrushing,diagStressStrain3(firstCrushing,5)*100,'r^','markersize',6,'linewidth',3)
xlim([0,totalLen])
ylim([-1.5,1.0])
set(gca,'XTick',[],'YTick',-1.5:0.5:1)
ylabel({'Diagonal E1','strain (%)'})

subplot(5,1,4)
hold on
box on
plot(diagStressStrain3(:,4),'k','linewidth',2)
plot([1,totalLen],[0,0],'k')
plot(firstSoftening,diagStressStrain3(firstSoftening,4),'co','markersize',6,'linewidth',3)
plot(firstCrushing,diagStressStrain3(firstCrushing,4),'r^','markersize',6,'linewidth',3)
xlim([0,totalLen])
ylim([-3.0,1.0])
set(gca,'XTick',[],'YTick',-3:1:1)
ylabel({'Diagonal E1','stress (ksi)'})

subplot(5,1,5)
hold on
box on
plot(-1,-1,'co','markersize',6,'linewidth',3)
plot(-1,-1,'r^','markersize',6,'linewidth',3)
plot(diagBeta(:,7),'k','linewidth',2)
plot(firstSoftening,diagBeta3(firstSoftening,3),'co','markersize',6,'linewidth',3)
plot(firstCrushing,diagBeta3(firstCrushing,3),'r^','markersize',6,'linewidth',3)
legend('diagonal \epsilon \leq -0.2%','diagonal \epsilon \leq -0.41%','Location','SE')
plot([1,totalLen],[0,0],'k')
xlim([0,totalLen])
ylim([0,1])
set(gca,'XTick',[],'YTick',0:0.25:1)
ylabel({'Diagonal E1','\beta'})
xlabel('pseudo-time')